@@ -21,8 +21,8 @@
 #ifndef CVSSERVICE_UTILS_H
 #define CVSSERVICE_UTILS_H
 
+#include <QStringList>
 class QString;
-class QStringList;
 
 
 namespace CvsServiceUtils
@@ -30,7 +30,7 @@ namespace CvsServiceUtils
 
 /**
  * Joins a list of file names to one QString and quotes
- * each name properly for usage with K3Process.
+ * each name properly for usage with QProcess.
  */
 QString joinFileList(const QStringList& files);
 
